<?php
/*
 *
 * MensajitosLib V0.3.1
 * Actualizado el 14/07/2006_**
 * Este programa es propiedad intelectual de
 * Mario Enrique Gomez Argueta. Su uso y distribucion
 * esta permitida bajo los terminos de la licencia
 * GNU/GPL 2.0, que puede ser obtenida en
 * http://www.fsf.org/
 *
 * Este programa hace uso de la libreria Snoopy
 * distribuida tambien bajo la licencia GNU/GPL.
 * Para mayor informacion visitar:
 * http://snoopy.sourceforge.net/
 *
 */
include_once(dirname(__FILE__)."/Config.php");

// Si no se ha definido el modo debug
if(isset($display_errors)) {
  define("MENSAJITOS_DEBUG",$display_errors);
} else {
  define("MENSAJITOS_DEBUG",true);
}

// Definimos las constantes de directorios para
// poder accesarlas desde todo el codigo
if(isset($module_base)) {
  define("MENSAJITOS_MOD_DIR",$module_base);
} else {
  define("MENSAJITOS_MOD_DIR","");
  if(MENSAJITOS_DEBUG)
    echo "<br />Error: No se ha definido \$module_base en Config.php";
}

if(isset($libdir)) {
  define("MENSAJITOS_LIB_DIR",$libdir);
} else {
  define("MENSAJITOS_LIB_DIR","");
  if(MENSAJITOS_DEBUG)
    echo "<br />Error: No se ha definido \$libdir en Config.php";
}

// Intentamos cargar las bibliotecas.
loadLibs(MENSAJITOS_LIB_DIR);

// Funcion de carga de las bibliotecas
function loadLibs($libdir){
  $libconfig = $libdir."/libconf.php.inc";

  if(!file_exists($libconfig)) {
    if(MENSAJITOS_DEBUG)
      echo "<br />Error: No existe el archivo de configuracion de bibliotecas libconf.php.inc";
  }

  include_once($libconfig);

  if(!isset($libfiles)) {
    if(MENSAJITOS_DEBUG)
      echo "Error: No se ha establecido la variable libfiles";
  }

  if(is_array($libfiles)) {
    foreach($libfiles as $i=>$val) {
      include_once($libdir."/".$val);
    }
  } else {
    include_once($libdir."/".$libfiles);
  }
}

// Funciones de procesamiento de plantillas

// Procesar plantilla abre el archivo especificado
// Y evalua los valores del arreglo asociativo pasado como parametro
// El valor textual del indice se sustituye por su valor correspondiente
// asi si definimos $var["(sustituyeme)"] = "Hola Mundo!!";
// Todas las ocurrencias de (sustituyeme) en el archivo especificado
// serian sustituidas por "Hola Mundo!!!"
// Si no se puede abrir el archivo, la funcion retorna NULL
// Nota: Esta funcion no esta optimizada para archivos grandes o para
// grandes cantidades de variables. Aunque para plantillas deberia de
// Funcionar correctamente
function procesarPlantilla($archivo,$valores) {
  if(is_file($archivo)) { // Revisa si el archivo existe
    $buffer = file_get_contents($archivo);
    foreach($valores as $var=>$val) { // Sustituimos cada valor del arreglo
      $buffer = str_replace($var,$val,$buffer);
    }
    return $buffer; // Devolvemos el archivo
  } else
    return NULL; // Devolvemos NULL si no hay archivo
}

function procesarPlantillaStr($buffer,$valores) {
  foreach($valores as $var=>$val) { // Sustituimos cada valor del arreglo
    $buffer = str_replace($var,$val,$buffer);
  }
  return $buffer; // Devolvemos el string
}


class Mensajitos {
  // Registro de modulos cargados
  var $modulos = array();

  function __constructor() {
    $this->loadModules();
  }
  // Carga de los modulos
  // funcion compatibilidad PHP4
  function Mensajitos() {
    $this->loadModules();
  }

  // Revisa si el PHP es un modulo valido
  function checkModule($module_base,$module_name) {
    $module_file = $module_base."/".$module_name.".php";
    include_once($module_file);
    $function1 = $module_name."_checkPhone";
    $function2 = $module_name."_getOperator";
    $function3 = $module_name."_sendSMS";
    if(is_callable($function1)&&
       is_callable($function2)&&
       is_callable($function3)) {
      return true;
    }
    return false;
  }

// Inicio de funcion de carga de mdulos

// Cada modulo tiene la forma:
// function <nombreModulo>_checkPhone(<telefono>) {}
// function <nombreModulo>_getOperator() {}
// function <nombreModulo>_sendSMS(<telefono>,<mensaje>,<remitente>) {}

  function loadModules() {
    $module_base = MENSAJITOS_MOD_DIR;
    $modulos = array();
    // Se abre el directorio de mdulos
    if ($gestor = opendir($module_base)) {

       // Se obtiene el nombre de cada archivo;
      while (false !== ($archivo = readdir($gestor))) {

        // Se revisan los archivos existentes
        if ($archivo != "." && $archivo != ".." && is_file($module_base."/".$archivo) ) {

          // Verificamos que se trate de un php
          if(ereg("^(.*)\.[pP][hH][pP]$",$archivo,$reg)) {
            if($this->checkModule($module_base,$reg[1])) {
              $modulos[] = $reg[1];
            }
          }
        }
      }
      $this->modulos = $modulos;
      closedir($gestor);
    }
  }

  // Devuelve el nombre del operador
  // para el modulo especificado
  function nombreOperador($modulo) {
    $function = $modulo."_getOperator";
    return $function();
  }

  // Detecta el operador en base al numero de telefono
  function detectarOperador($telefono) {
    return $this->nombreOperador($this->detectarModulo($telefono));
  }

  // Detecta el modulo a utilizar en base al numero de telefono
  function detectarModulo($telefono) {
    foreach($this->modulos as $index=>$module_name) {
      $function = $module_name."_checkPhone";
      if($function($telefono)) {
        return $module_name;
      }
    }
    return NULL;
  }

  // Envia un mensaje de texto al telefono especificado
  function enviarMensaje($telefono,$mensaje,$firma) {
    $modulo = $this->detectarModulo($telefono);
    if($modulo!=NULL) {
      $send = $modulo."_sendSMS";
      if($send($telefono,$mensaje,$firma)) {
        return true;
      }
    }
    return false;
  }
}

// Funcion de compatibilidad detectarOperador
function detectarCompania($telefono) {
  $mensajitos = new Mensajitos;
  return $mensajitos->detectarOperador($telefono);
}

// Funcion de compatibilidad enviarMensaje
function enviarMensaje($telefono,$mensaje,$firma) {
   $mensajitos = new Mensajitos;
   return $mensajitos->enviarMensaje($telefono,$mensaje,$firma);
}
?>